package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcBudget;

/**
 * cmc预算管理Service接口
 * 
 * @author cmc
 * @date 2024-03-22
 */
public interface ICmcBudgetService 
{
    /**
     * 查询cmc预算管理
     * 
     * @param budgetId cmc预算管理主键
     * @return cmc预算管理
     */
    public CmcBudget selectCmcBudgetByBudgetId(String budgetId);

    /**
     * 查询cmc预算管理列表
     * 
     * @param cmcBudget cmc预算管理
     * @return cmc预算管理集合
     */
    public List<CmcBudget> selectCmcBudgetList(CmcBudget cmcBudget);

    /**
     * 新增cmc预算管理
     * 
     * @param cmcBudget cmc预算管理
     * @return 结果
     */
    public int insertCmcBudget(CmcBudget cmcBudget);

    /**
     * 修改cmc预算管理
     * 
     * @param cmcBudget cmc预算管理
     * @return 结果
     */
    public int updateCmcBudget(CmcBudget cmcBudget);

    /**
     * 批量删除cmc预算管理
     * 
     * @param budgetIds 需要删除的cmc预算管理主键集合
     * @return 结果
     */
    public int deleteCmcBudgetByBudgetIds(String[] budgetIds);

    /**
     * 删除cmc预算管理信息
     * 
     * @param budgetId cmc预算管理主键
     * @return 结果
     */
    public int deleteCmcBudgetByBudgetId(String budgetId);
}
